#!/bin/bash
###############################################################
# Trial list 1.2 by Turranius - http://www.grandis.nu/glftpd  #
#                                                             #
# This little script is a complement to tur-trial.            #
# It will, when run from cron, check all users, and check     #
# if they are in TRiAL or TRiAL-2 and output the uploaded     #
# megabytes to a logfile.                                     #
# That way, you dont have to sit infront of irc and do        #
# !passed <user> right before the stats reset. Just check     #
# the log file the next day, del any users who didnt pass     #
# and move any TRiAL-2 users to the TRiAL group.              #
# Those who passed trial should be taken out of the TRiAL     #
# group of course :)                                          #
#                                                             #
# Installation:                                               #
# Put this one in /glftpd/bin or where ever you have          #
# glftpd. Make it executable.                                 #
# change the parameters below to suit your system             #
# Try to run it from shell and check the logfile when its     #
# done. Make sure it works before crontabbing it.             #
#                                                             #
# Add it to crontab. Most people have the reset bin start     #
# a new week on Sunday at 00:00, and if thats so, this should # 
# do, for weekly trials:                                      #
# 57 23 * * 6 /glftpd/bin/triallist_1.1.sh                    #
# For montly trials, run it at the last day of the month, at  #
# 23:57 (11:57PM) or something.                               #
#                                                             #
###############################################################
# Version history:                                            #
# 1.2: Handles up to 9 stat sections.                         #
#      Not checking how much users upped that are not on      #
#      trial so should be a lot faster.                       #
#      Added LIMIT so you can see in the log if they passed   #
#      or not.                                                #
# 1.1: Changed it from two scripts into one.                  #
#      Cleaned up a little for public release.                #
#      Added montly trial support.                            #
# 1.0: Initial release.                                       #
###############################################################

LIMIT="1500"                                     # Trial limit in MB.
USERSFOLDER=/glftpd/ftp-data/users               # Path to users. Not chrooted.
LOGFILE=/glftpd/ftp-data/logs/triallog.log       # Logfile to write to.
DURATION="W"                                     # W = weekly. M = monthly trial.
DIREXCLUDE='default.user|glftpd|backup|disabled' # If you have folders in your users dir,
                                                 # add them here. 

###############################################################
# No changes should be needed below here.                     #
###############################################################

date=`date +%m%d`
touch $LOGFILE

## Do we want weekly or monthly trials?
case $DURATION in
 W)
   DUR="WKUP"
   DURNAME="week"
   ;;
 M)
   DUR="MONTHUP"
   DURNAME="month"
   ;;
 *)
   echo "Duration not set right. Either W or M" >> $LOGFILE
   exit 0
   ;;
esac

USERGROUPS=""

echo "-- Trial $DURNAME ended $date. Limit is $LIMIT MB / $DURNAME --" >> $LOGFILE
echo "----------------------------" >> $LOGFILE
cd $USERSFOLDER

for i in `ls -f -A | sort | egrep -v 'default.user|glftpd|backup|disabled'`; do
  for groups in `cat $i | grep -w GROUP | awk -F" " '{print $2}'`; do
    if [ "$groups" = "TRiAL" -o "$groups" = "TRiAL-2" ]; then
      if [ "$LAST" != "$i" ]; then
        USERGROUPS="$groups $USERGROUPS"
      fi

      UP="$( cat $i | grep $DUR | awk -F" " '{print $3}')"

      ## Check for other stat sections.
      UP2="$( grep -w $DUR $i | awk -F" " '{print $6}')"
      if [ "$UP2" != "" ]; then
        UP3="$(grep -w $DUR $i | awk -F" " '{print $9}')"
        if [ "$UP3" != "" ]; then
          UP4="$(grep -w $DUR $i | awk -F" " '{print $12}')"
          if [ "$UP4" != "" ]; then
            UP5="$(grep -w $DUR $i | awk -F" " '{print $15}')"
            if [ "$UP5" != "" ]; then
              UP6="$(grep -w $DUR $i | awk -F" " '{print $18}')"
              if [ "$UP6" != "" ]; then
              UP7="$(grep -w $DUR $i | awk -F" " '{print $21}')"
                if [ "$UP7" != "" ]; then
                  UP8="$(grep -w $DUR $i | awk -F" " '{print $24}')"
                  if [ "$UP8" != "" ]; then
                    UP9="$(grep -w $DUR $i | awk -F" " '{print $27}')"
                    if [ "$UP9" != "" ]; then
                      UP="$( expr "$UP" \+ "$UP2" \+ "$UP3" \+ "$UP4" \+ "$UP5" \+ "$UP6" \+ "$UP7" \+ "$UP8" \+ "$UP9" )"
                    else
                      UP="$( expr "$UP" \+ "$UP2" \+ "$UP3" \+ "$UP4" \+ "$UP5" \+ "$UP6" \+ "$UP7" \+ "$UP8" )"
                    fi
                  else
                    UP="$( expr "$UP" \+ "$UP2" \+ "$UP3" \+ "$UP4" \+ "$UP5" \+ "$UP6" \+ "$UP7" )"
                  fi
                else
                  UP="$( expr "$UP" \+ "$UP2" \+ "$UP3" \+ "$UP4" \+ "$UP5" \+ "$UP6" )"
                fi
              else
                UP="$( expr "$UP" \+ "$UP2" \+ "$UP3" \+ "$UP4" \+ "$UP5" )"
              fi
            else
              UP="$( expr "$UP" \+ "$UP2" \+ "$UP3" \+ "$UP4" )"
            fi
          else
            UP="$( expr "$UP" \+ "$UP2" \+ "$UP3" )"
          fi
        else
          UP="$( expr "$UP" \+ "$UP2" )"
        fi
      fi
      UP="$( expr $UP \/ 1024 )"

      if [ "$UP" -gt "$LIMIT" ]; then
        echo "$i $USERGROUPS Passed with: $UP"MB"" >> $LOGFILE
      else
        echo "$i $USERGROUPS Failed with: $UP"MB"" >> $LOGFILE
      fi
    fi
  done
  LAST="$i"
  USERGROUPS=""
done

echo " " >> $LOGFILE

exit 0